@@ -11,6 +11,7 @@
 
 namespace OCA\Passwords\EventListener\User;
 
+use OCP\User\Events\PasswordUpdatedEvent;
 use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventListener;
 use OCP\ISession;
@@ -21,7 +22,7 @@ class UserPasswordChangedListener implements IEventListener {
     }
 
     /**
-     * @param Event|\OCP\User\Events\PasswordUpdatedEvent  $event
+     * @param Event|PasswordUpdatedEvent $event
      *
      * @return void
      */
