@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\Challenge;
@@ -17,19 +21,13 @@ use OCP\EventDispatcher\Event;
  */
 class GenericChallengeEvent extends Event {
 
-    /**
-     * @var Challenge
-     */
-    protected Challenge $Challenge;
-
     /**
      * GenericChallengeEvent constructor.
      *
      * @param Challenge $Challenge
      */
-    public function __construct(Challenge $Challenge) {
+    public function __construct(protected Challenge $Challenge) {
         parent::__construct();
-        $this->Challenge = $Challenge;
     }
 
     /**
