@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\FolderRevision;
@@ -17,21 +21,6 @@ use OCP\EventDispatcher\Event;
  */
 class BeforeFolderRevisionClonedEvent extends Event {
 
-    /**
-     * @var FolderRevision
-     */
-    protected FolderRevision $original;
-
-    /**
-     * @var FolderRevision
-     */
-    protected FolderRevision $clone;
-
-    /**
-     * @var array
-     */
-    protected array          $overwrites;
-
     /**
      * BeforeFolderRevisionClonedEvent constructor.
      *
@@ -39,11 +28,8 @@ class BeforeFolderRevisionClonedEvent extends Event {
      * @param FolderRevision $clone
      * @param array          $overwrites
      */
-    public function __construct(FolderRevision $original, FolderRevision $clone, array $overwrites) {
+    public function __construct(protected FolderRevision $original, protected FolderRevision $clone, protected array $overwrites) {
         parent::__construct();
-        $this->original   = $original;
-        $this->clone      = $clone;
-        $this->overwrites = $overwrites;
     }
 
     /**
