@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\Password;
@@ -17,21 +21,6 @@ use OCP\EventDispatcher\Event;
  */
 class BeforePasswordClonedEvent extends Event {
 
-    /**
-     * @var Password
-     */
-    protected Password $original;
-
-    /**
-     * @var Password
-     */
-    protected Password $clone;
-
-    /**
-     * @var array
-     */
-    protected array    $overwrites;
-
     /**
      * BeforePasswordClonedEvent constructor.
      *
@@ -39,11 +28,8 @@ class BeforePasswordClonedEvent extends Event {
      * @param Password $clone
      * @param array    $overwrites
      */
-    public function __construct(Password $original, Password $clone, array $overwrites) {
+    public function __construct(protected Password $original, protected Password $clone, protected array $overwrites) {
         parent::__construct();
-        $this->original = $original;
-        $this->clone = $clone;
-        $this->overwrites = $overwrites;
     }
 
     /**
