@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\PasswordRevision;
@@ -17,21 +21,6 @@ use OCP\EventDispatcher\Event;
  */
 class BeforePasswordRevisionClonedEvent extends Event {
 
-    /**
-     * @var PasswordRevision
-     */
-    protected PasswordRevision $original;
-
-    /**
-     * @var PasswordRevision
-     */
-    protected PasswordRevision $clone;
-
-    /**
-     * @var array
-     */
-    protected array            $overwrites;
-
     /**
      * BeforePasswordRevisionClonedEvent constructor.
      *
@@ -39,11 +28,8 @@ class BeforePasswordRevisionClonedEvent extends Event {
      * @param PasswordRevision $clone
      * @param array            $overwrites
      */
-    public function __construct(PasswordRevision $original, PasswordRevision $clone, array $overwrites) {
+    public function __construct(protected PasswordRevision $original, protected PasswordRevision $clone, protected array $overwrites) {
         parent::__construct();
-        $this->original = $original;
-        $this->clone = $clone;
-        $this->overwrites = $overwrites;
     }
 
     /**
