@@ -11,6 +11,7 @@
 
 namespace OCA\Passwords\Exception\Database;
 
+use Throwable;
 use Exception;
 use OCA\Passwords\Db\AbstractRevision;
 
@@ -19,9 +20,9 @@ class DecryptedDataException extends Exception {
     /**
      * @param AbstractRevision $revision
      * @param int              $code
-     * @param \Throwable|null  $previous
+     * @param Throwable|null $previous
      */
-    public function __construct(AbstractRevision $revision, int $code = 0, ?\Throwable $previous = null) {
+    public function __construct(AbstractRevision $revision, int $code = 0, ?Throwable $previous = null) {
         parent::__construct("Can not save decrypted revision {$revision->getUuid()}", $code, $previous);
     }
 }
\ No newline at end of file
