@@ -13,11 +13,11 @@ namespace OCA\Passwords\Helper\Token;
 
 use Exception;
 use OCP\Authentication\Token\IProvider;
-use OCP\Authentication\Token\IToken;
 use OCA\Passwords\Services\ConfigurationService;
 use OCA\Passwords\Services\EnvironmentService;
 use OCA\Passwords\Services\LoggingService;
 use OCA\Passwords\Services\SessionService;
+use OCP\Authentication\Token\IToken as OCPIToken;
 use OCP\IL10N;
 use OCP\IRequest;
 use OCP\Security\ISecureRandom;
@@ -90,7 +90,7 @@ class ApiTokenHelper {
         $userLogin = $this->environment->getUserLogin();
         $token     = $this->generateRandomDeviceToken();
         $password  = $this->getUserPassword();
-        $type      = $permanent ? IToken::PERMANENT_TOKEN:IToken::TEMPORARY_TOKEN;
+        $type      = $permanent ? OCPIToken::PERMANENT_TOKEN:OCPIToken::TEMPORARY_TOKEN;
 
         $deviceToken = $this->tokenProvider->generateToken($token, $this->userId, $userLogin, $password, $name, $type);
         $deviceToken->setScope(['filesystem' => $this->mustHaveFileSystemPermission()]);
